@@ -1,5 +1,6 @@
 #include <catch.hpp>
 #include "test_utils.hpp"
+#include "fixtures.hpp"
 
 #include <boost/algorithm/string/replace.hpp>
 
@@ -37,7 +38,7 @@ static shared_value parse(string s) {
 TEST_CASE("invalid conf throws") {
     for (auto const& invalid : whitespace_variations(invalid_conf(), false)) {
         CAPTURE(invalid.test);
-        REQUIRE_THROWS_AS(parse(invalid.test), config_exception);
+        REQUIRE_THROWS_AS(parse(invalid.test), config_exception&);
     }
 }
 
@@ -116,8 +117,8 @@ TEST_CASE("path parsing") {
     REQUIRE(path(vector<string>{"1", "2", "3", "4"}) == parse_path("1.2.3.4"));
 
     for (string invalid : {"", " ", "  \n   \n  ", "a.", ".b", "a..b", "a${b}c", "\"\".", ".\"\""}) {
-        REQUIRE_THROWS_AS(parse_without_resolving("[${"+invalid+"}]"), bad_path_exception);
-        REQUIRE_THROWS_AS(path_parser::parse_path(invalid), bad_path_exception);
+        REQUIRE_THROWS_AS(parse_without_resolving("[${"+invalid+"}]"), bad_path_exception&);
+        REQUIRE_THROWS_AS(path_parser::parse_path(invalid), bad_path_exception&);
     }
 }
 
@@ -243,9 +244,9 @@ TEST_CASE("implied comma handling") {
     auto no_newline_at_end = parse_config("a : b");
     REQUIRE("b" == no_newline_at_end->get_string("a"));
 
-    REQUIRE_THROWS_AS(parse_config("{ a : y b : z }"), config_exception);
+    REQUIRE_THROWS_AS(parse_config("{ a : y b : z }"), config_exception&);
 
-    REQUIRE_THROWS_AS(parse_config(R"({ "a" : "y" "b" : "z" })"), config_exception);
+    REQUIRE_THROWS_AS(parse_config(R"({ "a" : "y" "b" : "z" })"), config_exception&);
 
     // with no newline or comma, we do value concatenation
     auto no_newline_in_array = parse_config(" { c : [ 1 2 3 ] } ");
@@ -641,7 +642,7 @@ TEST_CASE("include file with extension") {
     auto conf = config::parse_string("include file(\"" + fixture_path("test01.conf") + "\")");
 
     REQUIRE(42u == conf->get_int("ints.fortyTwo"));
-    REQUIRE_THROWS_AS(conf->get_int("fromJson1"), config_exception);
+    REQUIRE_THROWS_AS(conf->get_int("fromJson1"), config_exception&);
 }
 
 TEST_CASE("include file whitespace inside parens") {
@@ -718,3 +719,19 @@ TEST_CASE("accept multi period numeric path") {
     auto conf3 = config::parse_string("ABC.0.1.2.3=foobar3");
     REQUIRE("foobar3" == conf3->get_string("ABC.0.1.2.3"));
 }
+
+
+TEST_CASE("parse files") {
+    string cur_file_path(TEST_FILE_DIR);
+    string file_path1 = cur_file_path + "/simple_confs/a.conf";
+    string file_path2 = cur_file_path + "/simple_confs/sub/b.conf";
+    auto conf1 = config::parse_file_any_syntax(move(file_path1))->resolve();
+    auto conf2 = config::parse_file_any_syntax(move(file_path2))->resolve();
+    REQUIRE("adsf" == conf1->get_string("Peter.passwd1"));
+    REQUIRE("lsdk" == conf1->get_string("Peter.passwd2"));
+    REQUIRE("123414" == conf1->get_string("Peter.passwd3"));
+    REQUIRE("qwer.,m" == conf1->get_string("Peter.passwd4"));
+    REQUIRE(10 == conf1->get_int("Peter.passwd5"));
+    REQUIRE("nick" == conf2->get_string("other_field.nick_name"));
+    REQUIRE("qwer.,m" == conf2->get_string("other_field.new_passwd"));
+}
